@@ -1,5 +1,5 @@
 #!/bin/sh
 
 
-IMAGE="ghcr.io/polyverse/rust-dev-env/rust-dev-env"
+IMAGE="ghcr.io/archisgore/rust-dev-env"
 docker run -v cargo-cache:/root/.cargo/registry -v $PWD:/volume --rm -it --privileged $IMAGE
